@@ -1,6 +1,6 @@
 use 5.38.0;
 use experimental 'class';
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 class Game::Floppy {
 	use Raylib::App;
@@ -87,6 +87,9 @@ class Game::Floppy {
 	method handle_flappy () {
 		$floppy->y($floppy->y + 3);
 		$floppy->draw();
+		if ($floppy->y > $height || $floppy->y < 0) {
+			$game_over = 1;
+		}
 	}
 
 	method handle_tubes () {
@@ -133,7 +136,7 @@ Game::Floppy - Floppy bird using raylib
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
